summaryrefslogtreecommitdiffstats
path: root/kmag
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:52:23 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:52:23 -0600
commit92994ee2036ac7c4c68747f67dbc0ecbaf4c250c (patch)
treea7b8d21bab293fe30c6f1db1daa9544469fb5f37 /kmag
parent6687cd2515bdebbd8f0c92261f3acf8777441ca6 (diff)
downloadtdeaccessibility-92994ee2036ac7c4c68747f67dbc0ecbaf4c250c.tar.gz
tdeaccessibility-92994ee2036ac7c4c68747f67dbc0ecbaf4c250c.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'kmag')
-rw-r--r--kmag/kmag.cpp4
-rw-r--r--kmag/kmag.h2
-rw-r--r--kmag/kmagselrect.cpp16
-rw-r--r--kmag/kmagzoomview.cpp46
4 files changed, 34 insertions, 34 deletions
diff --git a/kmag/kmag.cpp b/kmag/kmag.cpp
index 2ee430c..8a58ac4 100644
--- a/kmag/kmag.cpp
+++ b/kmag/kmag.cpp
@@ -571,7 +571,7 @@ void KmagApp::saveZoomPixmap()
KMessageBox::error(0, i18n("Unable to upload file over the network."),
i18n("Error Writing File"));
} else {
- KMessageBox::information(0, i18n("Current zoomed image saved to\n%1").tqarg(url.prettyURL()),
+ KMessageBox::information(0, i18n("Current zoomed image saved to\n%1").arg(url.prettyURL()),
i18n("Information"), "save_confirm");
}
}
@@ -583,7 +583,7 @@ void KmagApp::saveZoomPixmap()
KMessageBox::error(0, i18n("Unable to save file. Please check if you have permission to write to the directory."),
i18n("Error Writing File"));
} else {
- KMessageBox::information(0, i18n("Current zoomed image saved to\n%1").tqarg(url.prettyURL()),
+ KMessageBox::information(0, i18n("Current zoomed image saved to\n%1").arg(url.prettyURL()),
i18n("Information"), "save_confirm");
}
}
diff --git a/kmag/kmag.h b/kmag/kmag.h
index aeee22b..445d51e 100644
--- a/kmag/kmag.h
+++ b/kmag/kmag.h
@@ -71,7 +71,7 @@ class KmagApp : public KMainWindow
protected:
- /** save general Options like all bar positions and status as well as the tqgeometry and the recent file list to the configuration
+ /** save general Options like all bar positions and status as well as the geometry and the recent file list to the configuration
* file
*/
void saveOptions();
diff --git a/kmag/kmagselrect.cpp b/kmag/kmagselrect.cpp
index 236bddf..73caf5a 100644
--- a/kmag/kmagselrect.cpp
+++ b/kmag/kmagselrect.cpp
@@ -184,19 +184,19 @@ void KMagSelRect::hide()
void KMagSelRect::update()
{
// make sure the selection window does not go outside of the display
- if (height() > TQApplication::desktop()->tqgeometry().height())
- setHeight (TQApplication::desktop()->tqgeometry().height());
- if (width() > TQApplication::desktop()->tqgeometry().width())
- setWidth (TQApplication::desktop()->tqgeometry().width());
+ if (height() > TQApplication::desktop()->geometry().height())
+ setHeight (TQApplication::desktop()->geometry().height());
+ if (width() > TQApplication::desktop()->geometry().width())
+ setWidth (TQApplication::desktop()->geometry().width());
if (top() < 0)
moveTop (0);
if (left() < 0)
moveLeft (0);
- if (bottom() > TQApplication::desktop()->tqgeometry().bottom())
- moveBottom (TQApplication::desktop()->tqgeometry().bottom());
- if (right() > TQApplication::desktop()->tqgeometry().right())
- moveRight (TQApplication::desktop()->tqgeometry().right());
+ if (bottom() > TQApplication::desktop()->geometry().bottom())
+ moveBottom (TQApplication::desktop()->geometry().bottom());
+ if (right() > TQApplication::desktop()->geometry().right())
+ moveRight (TQApplication::desktop()->geometry().right());
if (selectionwindow != 0)
selectionwindow->setSelRect (TQRect (topLeft(), bottomRight()));
diff --git a/kmag/kmagzoomview.cpp b/kmag/kmagzoomview.cpp
index 4dd9a12..47f6a46 100644
--- a/kmag/kmagzoomview.cpp
+++ b/kmag/kmagzoomview.cpp
@@ -80,22 +80,22 @@ static uchar phand_bits[] = {
static bool obscuredRegion (TQRegion &region, Window winId, Window ignoreId, Window start = 0, int level = -1) {
- Window root, parent, *tqchildren; uint ntqchildren;
+ Window root, parent, *children; uint nchildren;
if (0 == start)
start = qt_xrootwin();
bool winIdFound = false;
- if (0 != XQueryTree (qt_xdisplay(), start, &root, &parent, &tqchildren, &ntqchildren)) {
- for (uint i=0; i < ntqchildren; ++i) {
+ if (0 != XQueryTree (qt_xdisplay(), start, &root, &parent, &children, &nchildren)) {
+ for (uint i=0; i < nchildren; ++i) {
if (winIdFound) {
- if (ignoreId != tqchildren [i]) {
+ if (ignoreId != children [i]) {
XWindowAttributes atts;
- XGetWindowAttributes (qt_xdisplay(), tqchildren [i], &atts);
+ XGetWindowAttributes (qt_xdisplay(), children [i], &atts);
if (atts.map_state == IsViewable)
region -= TQRegion (atts.x, atts.y, atts.width, atts.height, TQRegion::Rectangle);
}
}
- else if (winId == tqchildren [i])
+ else if (winId == children [i])
winIdFound = true;
// According to tests, my own window ID is either on toplevel or two levels below.
@@ -103,15 +103,15 @@ static bool obscuredRegion (TQRegion &region, Window winId, Window ignoreId, Win
// then to five recursion levels, and make a full recursive search only if that
// was unsuccessful.
else if (level > 1)
- winIdFound = obscuredRegion (region, winId, ignoreId, tqchildren [i], level-1);
+ winIdFound = obscuredRegion (region, winId, ignoreId, children [i], level-1);
else if (level == -1)
- if (! (winIdFound = obscuredRegion (region, winId, ignoreId, tqchildren [i], 0)))
- if (! (winIdFound = obscuredRegion (region, winId, ignoreId, tqchildren [i], 1)))
- winIdFound = obscuredRegion (region, winId, ignoreId, tqchildren [i], -1);
+ if (! (winIdFound = obscuredRegion (region, winId, ignoreId, children [i], 0)))
+ if (! (winIdFound = obscuredRegion (region, winId, ignoreId, children [i], 1)))
+ winIdFound = obscuredRegion (region, winId, ignoreId, children [i], -1);
}
- if (tqchildren != NULL)
- XFree (tqchildren);
+ if (children != NULL)
+ XFree (children);
}
return winIdFound;
@@ -493,7 +493,7 @@ void KMagZoomView::mouseReleaseEvent(TQMouseEvent *e)
// set the mouse mode to normal
m_mouseMode = Normal;
- // restore the cursor tqshape
+ // restore the cursor shape
setCursor(arrowCursor);
// restore the cursor position
@@ -504,7 +504,7 @@ void KMagZoomView::mouseReleaseEvent(TQMouseEvent *e)
// set the mouse mode to normal
m_mouseMode = Normal;
- // restore the cursor tqshape
+ // restore the cursor shape
setCursor(arrowCursor);
// restore the cursor position
@@ -516,7 +516,7 @@ void KMagZoomView::mouseReleaseEvent(TQMouseEvent *e)
// set the mouse mode to normal
m_mouseMode = Normal;
- // restore the cursor tqshape
+ // restore the cursor shape
setCursor(arrowCursor);
}
break;
@@ -706,7 +706,7 @@ void KMagZoomView::fitToWindow()
m_selRect.moveCenter(currCenter);
m_selRect.update();
- viewport()->tqrepaint(false);
+ viewport()->repaint(false);
}
void KMagZoomView::setFitToWindow(bool fit)
@@ -755,14 +755,14 @@ void KMagZoomView::grabFrame()
intersection.translate (-selRect.x(), -selRect.y());
TQPainter painter (&m_grabbedPixmap, true);
- TQMemArray<TQRect> rects (intersection.tqrects());
+ TQMemArray<TQRect> rects (intersection.rects());
for (uint i = 0; i < rects.size(); i++)
painter.fillRect (rects[i], TQBrush (TQColor (128, 128, 128)));
// call tqrepaint to display the newly grabbed image
TQRect newSize = m_zoomMatrix.mapRect (m_grabbedPixmap.rect());
resizeContents (newSize.width(), newSize.height());
- viewport()->tqrepaint(false);
+ viewport()->repaint(false);
}
@@ -775,7 +775,7 @@ void KMagZoomView::updateMouseView()
if(m_selRect.left() <= pos.x() && pos.x() <= m_selRect.right() &&
m_selRect.top() <= pos.y() && pos.y() <= m_selRect.bottom() &&
m_refreshSwitch)
- viewport()->tqrepaint(false);
+ viewport()->repaint(false);
}
/**
@@ -801,7 +801,7 @@ void KMagZoomView::setZoom(float zoom)
{
m_zoom = zoom;
updateMatrix();
- viewport()->tqrepaint();
+ viewport()->repaint();
}
/**
@@ -811,7 +811,7 @@ void KMagZoomView::setRotation(int rotation)
{
m_rotation = rotation;
updateMatrix();
- viewport()->tqrepaint();
+ viewport()->repaint();
}
/**
@@ -820,7 +820,7 @@ void KMagZoomView::setRotation(int rotation)
void KMagZoomView::setInvertation(bool invert)
{
m_invert = invert;
- viewport()->tqrepaint();
+ viewport()->repaint();
}
/**
@@ -755,14 +755,14 @@ void KMagZoomView::grabFrame()
for (uint i = 0; i < rects.size(); i++)
painter.fillRect (rects[i], TQBrush (TQColor (128, 128, 128)));
- // call tqrepaint to display the newly grabbed image
+ // call repaint to display the newly grabbed image
TQRect newSize = m_zoomMatrix.mapRect (m_grabbedPixmap.rect());
resizeContents (newSize.width(), newSize.height());